# Licensed Materials - Property of IBM
# Rational ClearCase
# (C) Copyright IBM Corp. 2008, 2014.  All Rights Reserved.
# US Government Users Restricted Rights -
# Use, duplication or disclosure restricted by GSA ADP Schedule
# Contract with IBM Corp

#  This program is used to convert a ClearCase v7.0.x schedule file for use as
#  input to v7.1 "cleartool sched -set <filename>

use strict;

my $job_id_str = "Job.Id:";
my $job_name_str = "Job.Name:";
my $job_task_str = "Job.Task:";
my $job_follows_str = "Job.Schedule.Sequential.FollowsJob:";
my $comment_str = "# ";
my $line_count = 0;

my $numargs = $#ARGV + 1;
if ($numargs != 1) {
    print "ERROR: $numargs command line arguments specified, 1 expected.\n";
    print "Usage:\n";
    print "      ratlperl sched_conv.pl <schedule_filename>\n";
    print "\n";
    exit;
}

my $schedfilename = $ARGV[0];
my $newschedfilename = $schedfilename . ".new";

print "Processing input file \"$schedfilename\"\n";

#  Open the schedule file for processing
open(SCHEDFILE, $schedfilename);
open(NEW_SCHEDFILE, ">$newschedfilename");

#  Process the schedlue file
while (!eof(SCHEDFILE)) {
    #  Get the next line from the file
    my $line = <SCHEDFILE>;
    my $next_line = "junk";
    my $char_pos = 0;

    $line_count++;

    if (($char_pos = index($line, $job_id_str)) >= 0)
    {
        #  Comment out the Job.Id line and
        #  Uncomment the job.Name line

        #  Put comment char on Job.ID line
        substr($line, $char_pos, 0) = "$comment_str";

        # The next line MUST be Job.Name
        $next_line = <SCHEDFILE>;
        $line_count++;
        $char_pos = index($next_line, $job_name_str);
        if ($char_pos >= 0) {
            $char_pos = index($next_line, $comment_str);
            substr($next_line, $char_pos, 2) = "";
            printf(NEW_SCHEDFILE $line);
            print(NEW_SCHEDFILE $next_line);
        } else {
            print "ERROR: Syntax error in \"$schedfilename\" near line $line_count\n";
            print "ERROR: Expected: $job_name_str\n";
            print "ERROR: Found: $next_line";
            print "ERROR: No output generated.\n";
            close(NEW_SCHEDFILE);
            unlink($newschedfilename);
            exit;
        }
    }
    elsif (($char_pos = index($line, $job_task_str)) >= 0)
    {
        #  Comment out the Job.Task ID line and
        #  Uncomment the job.Task Name line

        #  Put comment char on Job.Task ID line
        substr($line, $char_pos, 0) = "$comment_str";

        # The next line MUST be Job.Task Name
        $next_line = <SCHEDFILE>;
        $line_count++;
        $char_pos = index($next_line, $job_task_str);
        if ($char_pos >= 0) {
            $char_pos = index($next_line, $comment_str);
            substr($next_line, $char_pos, 2) = "";
            printf(NEW_SCHEDFILE $line);
            print(NEW_SCHEDFILE $next_line);
        } else {
            print "ERROR: Syntax error in \"$schedfilename\" near line $line_count\n";
            print "ERROR: Expected: $job_task_str\n";
            print "ERROR: Found: $next_line";
            print "ERROR: No output generated.\n";
            close(NEW_SCHEDFILE);
            unlink($newschedfilename);
            exit;
        }
    }
    elsif (($char_pos = index($line, $job_follows_str)) >= 0)
    {
        #  Comment out the Job.Task ID line and
        #  Uncomment the job.Task Name line

        #  Put comment char on Job.Task ID line
        substr($line, $char_pos, 0) = "$comment_str";

        # The next line MUST be Job.Task Name
        $next_line = <SCHEDFILE>;
        $line_count++;
        $char_pos = index($next_line, $job_follows_str);
        if ($char_pos >= 0) {
            $char_pos = index($next_line, $comment_str);
            substr($next_line, $char_pos, 2) = "";
            printf(NEW_SCHEDFILE $line);
            print(NEW_SCHEDFILE $next_line);
        } else {
            print "ERROR: Syntax error in \"$schedfilename\" near line $line_count\n";
            print "ERROR: Expected: $job_follows_str\n";
            print "ERROR: Found: $next_line";
            print "ERROR: No output generated.\n";
            close(NEW_SCHEDFILE);
            unlink($newschedfilename);
            exit;
        }
    }
    else
    {
        printf(NEW_SCHEDFILE $line);
    }
}

#  Close the schedule file
close(SCHEDFILE);
close(NEW_SCHEDFILE);
print "Reformated scheduler file written to: \"$newschedfilename\"\n";
